@@ -28,6 +28,7 @@ public abstract class GeneratorBase extends JsonGenerator
      * 
      * @since 2.5
      */
+    @SuppressWarnings("deprecation")
     protected final static int DERIVED_FEATURES_MASK =
             Feature.WRITE_NUMBERS_AS_STRINGS.getMask()
             | Feature.ESCAPE_NON_ASCII.getMask()
@@ -100,6 +101,7 @@ public abstract class GeneratorBase extends JsonGenerator
     /**********************************************************
      */
 
+    @SuppressWarnings("deprecation")
     protected GeneratorBase(int features, ObjectCodec codec) {
         super();
         _features = features;
@@ -113,6 +115,7 @@ public abstract class GeneratorBase extends JsonGenerator
     /**
      * @since 2.5
      */
+    @SuppressWarnings("deprecation")
     protected GeneratorBase(int features, ObjectCodec codec, JsonWriteContext ctxt) {
         super();
         _features = features;
@@ -135,7 +138,9 @@ public abstract class GeneratorBase extends JsonGenerator
 
     @Override
     public void setCurrentValue(Object v) {
-        _writeContext.setCurrentValue(v);
+        if (_writeContext != null) {
+            _writeContext.setCurrentValue(v);
+        }
     }
 
     /*
@@ -150,6 +155,7 @@ public abstract class GeneratorBase extends JsonGenerator
 
     //public JsonGenerator configure(Feature f, boolean state) { }
 
+    @SuppressWarnings("deprecation")
     @Override
     public JsonGenerator enable(Feature f) {
         final int mask = f.getMask();
@@ -169,6 +175,7 @@ public abstract class GeneratorBase extends JsonGenerator
         return this;
     }
 
+    @SuppressWarnings("deprecation")
     @Override
     public JsonGenerator disable(Feature f) {
         final int mask = f.getMask();
@@ -217,6 +224,7 @@ public abstract class GeneratorBase extends JsonGenerator
      *
      * @since 2.7
      */
+    @SuppressWarnings("deprecation")
     protected void _checkStdFeatureChanges(int newFeatureFlags, int changedFeatures)
     {
         if ((changedFeatures & DERIVED_FEATURES_MASK) == 0) {
@@ -284,10 +292,9 @@ public abstract class GeneratorBase extends JsonGenerator
     public void writeStartObject(Object forValue) throws IOException
     {
         writeStartObject();
-        if ((_writeContext != null) && (forValue != null)) {
-            _writeContext.setCurrentValue(forValue);
+        if (forValue != null) {
+            setCurrentValue(forValue);
         }
-        setCurrentValue(forValue);
     }
 
     /*
