@@ -6,22 +6,34 @@ import com.fasterxml.jackson.core.sym.CharsToNameCanonicalizer;
 import com.fasterxml.jackson.core.util.BufferRecycler;
 
 /**
- * Tests to verify [JACKSON-278]
+ * Tests to verify functioning of {@link Version} class.
  */
-public class TestVersions extends com.fasterxml.jackson.test.BaseTest
+public class TestVersions extends com.fasterxml.jackson.core.BaseTest
 {
     public void testCoreVersions() throws Exception
     {
         assertVersion(new JsonFactory().version());
-        JsonParser jp = new ReaderBasedJsonParser(getIOContext(), 0, null, null,
+        ReaderBasedJsonParser jp = new ReaderBasedJsonParser(getIOContext(), 0, null, null,
                 CharsToNameCanonicalizer.createRoot());
         assertVersion(jp.version());
         jp.close();
-        JsonGenerator jgen = new WriterBasedJsonGenerator(getIOContext(), 0, null, null);
+        JsonGenerator jgen = new WriterBasedJsonGenerator(getIOContext(), 0, null, null, '"');
         assertVersion(jgen.version());
         jgen.close();
     }
 
+    public void testMisc() {
+        Version unk = Version.unknownVersion();
+        assertEquals("0.0.0", unk.toString());
+        assertEquals("//0.0.0", unk.toFullString());
+        assertTrue(unk.equals(unk));
+
+        Version other = new Version(2, 8, 4, "",
+                "groupId", "artifactId");
+        assertEquals("2.8.4", other.toString());
+        assertEquals("groupId/artifactId/2.8.4", other.toFullString());
+    }
+    
     /*
     /**********************************************************
     /* Helper methods
@@ -30,7 +42,7 @@ public class TestVersions extends com.fasterxml.jackson.test.BaseTest
     
     private void assertVersion(Version v)
     {
-    	assertEquals(PackageVersion.VERSION, v);
+        assertEquals(PackageVersion.VERSION, v);
     }
 
     private IOContext getIOContext() {
