@@ -24,13 +24,16 @@ public class TestParserClosing
     {
         final String DOC = "[ 1 ]";
 
-        JsonFactory f = new JsonFactory();
-
         // Check the default settings
-        assertTrue(f.isEnabled(JsonParser.Feature.AUTO_CLOSE_SOURCE));
+        assertTrue(sharedStreamFactory().isEnabled(StreamReadFeature.AUTO_CLOSE_SOURCE));
         // then change
-        f.disable(JsonParser.Feature.AUTO_CLOSE_SOURCE);
-        assertFalse(f.isEnabled(JsonParser.Feature.AUTO_CLOSE_SOURCE));
+        JsonFactory f = JsonFactory.builder()
+                .disable(StreamReadFeature.AUTO_CLOSE_SOURCE)
+                .build();
+        assertFalse(f.isEnabled(StreamReadFeature.AUTO_CLOSE_SOURCE));
+        {
+            assertFalse(f.isEnabled(JsonParser.Feature.AUTO_CLOSE_SOURCE));
+        }
         @SuppressWarnings("resource")
         MyReader input = new MyReader(DOC);
         JsonParser jp = f.createParser(input);
@@ -53,9 +56,9 @@ public class TestParserClosing
     {
         final String DOC = "[ 1 ]";
 
-        JsonFactory f = new JsonFactory();
-        f.enable(JsonParser.Feature.AUTO_CLOSE_SOURCE);
-        assertTrue(f.isEnabled(JsonParser.Feature.AUTO_CLOSE_SOURCE));
+        JsonFactory f = JsonFactory.builder()
+                .enable(StreamReadFeature.AUTO_CLOSE_SOURCE)
+                .build();
         MyReader input = new MyReader(DOC);
         JsonParser jp = f.createParser(input);
         assertFalse(input.isClosed());
@@ -79,9 +82,9 @@ public class TestParserClosing
     public void testNoAutoCloseInputStream() throws Exception
     {
         final String DOC = "[ 1 ]";
-        JsonFactory f = new JsonFactory();
-
-        f.disable(JsonParser.Feature.AUTO_CLOSE_SOURCE);
+        JsonFactory f = JsonFactory.builder()
+                .disable(StreamReadFeature.AUTO_CLOSE_SOURCE)
+                .build();
         MyStream input = new MyStream(DOC.getBytes("UTF-8"));
         JsonParser jp = f.createParser(input);
 
