@@ -4,7 +4,7 @@ import com.fasterxml.jackson.core.Version;
 import com.fasterxml.jackson.core.json.PackageVersion;
 import com.fasterxml.jackson.core.json.UTF8JsonGenerator;
 
-public class TestVersionUtil extends com.fasterxml.jackson.test.BaseTest
+public class TestVersionUtil extends com.fasterxml.jackson.core.BaseTest
 {
     public void testVersionPartParsing()
     {
@@ -19,6 +19,7 @@ public class TestVersionUtil extends com.fasterxml.jackson.test.BaseTest
                 VersionUtil.parseVersion("1.2.15-foo", "group", "artifact"));
     }
 
+    @SuppressWarnings("deprecation")
     public void testMavenVersionParsing() {
         assertEquals(new Version(1, 2, 3, "SNAPSHOT", "foo.bar", "foo-bar"),
                 VersionUtil.mavenVersionFor(TestVersionUtil.class.getClassLoader(), "foo.bar", "foo-bar"));
@@ -27,4 +28,10 @@ public class TestVersionUtil extends com.fasterxml.jackson.test.BaseTest
     public void testPackageVersionMatches() {
         assertEquals(PackageVersion.VERSION, VersionUtil.versionFor(UTF8JsonGenerator.class));
     }
+
+    // [core#248]: make sure not to return `null` but `Version.unknownVersion()`
+    public void testVersionForUnknownVersion() {
+        // expecting return version.unknownVersion() instead of null
+        assertEquals(Version.unknownVersion(), VersionUtil.versionFor(TestVersionUtil.class));
+    }
 }
